@@ -11,7 +11,7 @@ from uuid import uuid4
 from tornado import web
 from tornado import gen
 
-from litedfs.name.handlers.base import BaseHandler, BaseSocketHandler
+from litedfs.name.handlers.base import BaseHandler, BaseSocketHandler, auth_check
 from litedfs.name.utils.fs_core import FileSystemTree, InvalidValueError, SameNameExistsError, TargetPathMustDirectoryError, TargetPathNotExistsError, SourcePathNotExistsError, FileNotExistsError, SameNameFileExistsError
 from litedfs.name.utils.listener import Connection
 from litedfs.name.utils.common import file_sha1sum, file_md5sum, Errors, splitall
@@ -21,6 +21,7 @@ LOG = logging.getLogger("__name__")
 
 
 class GenerateFileBlockListHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def get(self):
         result = {"result": Errors.OK}
@@ -76,7 +77,25 @@ class GenerateFileBlockListHandler(BaseHandler):
         self.finish()
 
 
+class ListFileLockHandler(BaseHandler):
+    @gen.coroutine
+    def get(self):
+        result = {"result": Errors.OK}
+        try:
+            fs = FileSystemTree.instance()
+            if fs:
+                result["data"] = fs.list_file_locks()
+            else:
+                Errors.set_result_error("ServiceNotReadyYet", result)
+        except Exception as e:
+            LOG.exception(e)
+            Errors.set_result_error("ServerException", result)
+        self.write(result)
+        self.finish()
+
+
 class UpdateFileLockHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def put(self):
         result = {"result": Errors.OK}
@@ -102,6 +121,7 @@ class UpdateFileLockHandler(BaseHandler):
 
 
 class CreateFileHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def post(self):
         result = {"result": Errors.OK}
@@ -159,6 +179,7 @@ class CreateFileHandler(BaseHandler):
 
 
 class MoveFileDirectoryHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def put(self):
         result = {"result": Errors.OK}
@@ -199,6 +220,7 @@ class MoveFileDirectoryHandler(BaseHandler):
 
 
 class RenameFileDirectoryHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def put(self):
         result = {"result": Errors.OK}
@@ -233,6 +255,7 @@ class RenameFileDirectoryHandler(BaseHandler):
 
 
 class UpdateFileHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def put(self):
         result = {"result": Errors.OK}
@@ -266,6 +289,7 @@ class UpdateFileHandler(BaseHandler):
 
 
 class DeleteFileHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def delete(self):
         result = {"result": Errors.OK}
@@ -292,6 +316,7 @@ class DeleteFileHandler(BaseHandler):
 
 
 class CreateDirectoryHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def post(self):
         result = {"result": Errors.OK}
@@ -322,6 +347,7 @@ class CreateDirectoryHandler(BaseHandler):
 
 
 class DeleteDirectoryHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def delete(self):
         result = {"result": Errors.OK}
@@ -348,6 +374,7 @@ class DeleteDirectoryHandler(BaseHandler):
 
 
 class ListDirectoryHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def get(self):
         result = {"result": Errors.OK}
@@ -380,6 +407,7 @@ class ListDirectoryHandler(BaseHandler):
 
 
 class GetFileBlockInfoHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def get(self):
         result = {"result": Errors.OK}
@@ -416,6 +444,7 @@ class GetFileBlockInfoHandler(BaseHandler):
 
 
 class IsFileHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def get(self):
         result = {"result": Errors.OK}
@@ -444,6 +473,7 @@ class IsFileHandler(BaseHandler):
 
 
 class IsDirectoryHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def get(self):
         result = {"result": Errors.OK}
@@ -472,6 +502,7 @@ class IsDirectoryHandler(BaseHandler):
 
 
 class PathInfoHandler(BaseHandler):
+    @auth_check
     @gen.coroutine
     def get(self):
         result = {"result": Errors.OK}
