@@ -60,6 +60,7 @@ class Errors(object):
         "TargetPathNotExists": {"name": "TargetPathNotExists", "message": "target path not exists"},
         "SourcePathNotExists": {"name": "SourcePathNotExists", "message": "source path not exists"},
         "ServiceNotReadyYet": {"name": "ServiceNotReadyYet", "message": "service not ready yet"},
+        "AuthError": {"name": "AuthError", "message": "permission denied"},
     }
 
     @classmethod
@@ -119,6 +120,11 @@ class OperationError(Exception):
         self.message = message
 
 
+class AuthError(Exception):
+    def __init__(self, message):
+        self.message = message
+
+
 def file_sha1sum(file_path):
     sha1 = hashlib.sha1()
     with open(file_path, 'rb') as f:
