@@ -101,6 +101,8 @@ def main():
     parser.add_argument("address", help = "name node address, host:port")
     parser.add_argument("-w", "--column_width", help = "column max width", type = int, default = 0)
     parser.add_argument("-v", "--version", action = 'version', version = '%(prog)s ' + __version__)
+    parser.add_argument("-u", "--user", help = "user name", default = "")
+    parser.add_argument("-p", "--password", help = "user password", default = "")
     subparsers = parser.add_subparsers(dest = "object", help = 'sub-command help')
 
     # operate with file
@@ -180,10 +182,12 @@ def main():
         address = args.address
         object = args.object
         operation = args.operation
+        user = args.user
+        password = args.password
         url = "http://%s/%s/%s" % (address, object, operation)
         if address:
             host, port = address.split(":")
-            ldfs = LiteDFSClient(host, port)
+            ldfs = LiteDFSClient(host, port, user = user, password = password)
             if object == "file":
                 if operation == "create":
                     try:
@@ -321,16 +325,15 @@ def main():
                             print(e)
             elif object == "cluster":
                 if operation == "info":
-                    r = requests.get(url)
-                    if r.status_code == 200:
-                        data = r.json()
+                    r = ldfs.cluster_info()
+                    if r:
                         if args.raw:
-                            print(json.dumps(data, indent = 4, sort_keys = True))
+                            print(json.dumps(r, indent = 4, sort_keys = True))
                         else:
-                            if data["result"] == "ok":
+                            if r["result"] == "ok":
                                 print("online nodes:")
                                 print_table_result(
-                                    data["info"]["online_nodes"],
+                                    r["info"]["online_nodes"],
                                     [
                                         "id",
                                         "node_id",
@@ -342,7 +345,7 @@ def main():
                                 )
                                 print("\noffline nodes:")
                                 print_table_result(
-                                    data["info"]["offline_nodes"],
+                                    r["info"]["offline_nodes"],
                                     [
                                         "id",
                                         "node_id",
@@ -354,13 +357,12 @@ def main():
                                 )
                             else:
                                 print_table_result(
-                                    [data],
+                                    [r],
                                     ["result", "message"],
                                     args
                                 )
                     else:
-                        print("error:\ncode: %s\ncontent: %s" % (r.status_code, r.content))
-                        
+                        print("get cluster info failed") 
     except Exception as e:
         logging.error(logging.traceback.format_exc())
 
