@@ -8,6 +8,7 @@ from tornado import web
 from tornado import gen
 
 from litedfs.tool.viewer.handlers.base import BaseHandler, BaseSocketHandler
+from litedfs.tool.viewer.utils.remote_storage import RemoteStorage
 from litedfs.tool.viewer.config import CONFIG
 
 LOG = logging.getLogger("__name__")
@@ -23,3 +24,12 @@ class ClusterHandler(BaseHandler):
                 self.get_name_http_host(),
                 CONFIG["name_http_port"])
         )
+
+
+class ClusterInfoHandler(BaseHandler):
+    @gen.coroutine
+    def get(self):
+        client = RemoteStorage(CONFIG["name_http_host"], CONFIG["name_http_port"], user = CONFIG["user"], password = CONFIG["password"])
+        result = client.cluster_info()
+        self.write(result)
+        self.finish()
